# pydatavolley

A python package for reading volleyball scouting files in DataVolley
format (\*.dvw). Work in progress.

### Installation

    pip install pydatavolley

### Example

Example file (using read_dv.DataVolley(None) will use example file) will
read if no path is provided:

``` python
import pandas as pd
from datavolley import read_dv
pd.set_option('display.max_rows', 50)
pd.set_option('display.max_columns', 500)
pd.set_option('display.width', 280)
dv_instance = read_dv.DataVolley(None)
df = dv_instance.get_plays()
print('All skills\n' + df[df['skill'].notna()].head(40).to_string())

print('Attacks filtered\n' + df[df['skill'] == 'Attack'].head(20).to_string())
```

    All skills
                                    match_id video_file_number video_time                code                      team player_number         player_name player_id      skill evaluation_code attack_code set_code set_type start_zone end_zone end_subzone num_players_numeric home_team_score visiting_team_score home_setter_position visiting_setter_position custom_code home_p1 home_p2 home_p3 home_p4 home_p5 home_p6 visiting_p1 visiting_p2 visiting_p3 visiting_p4 visiting_p5 visiting_p6 start_coordinate mid_coordinate end_coordinate point_phase   attack_phase set_number home_team_id visiting_team_id              point_won_by              serving_team            receiving_team  rally_number custom_code  possesion_number
    4   87d4a64f-3281-461c-886c-e890373fe706                 1        494   *19SM+~~~78A~~~00  University of Louisville            19     Shannon Shields   -296094      Serve               +         NaN      NaN      NaN          7        8           A                 NaN              01                  00                    1                        6          00      19       9      11      15      10       7           1          16          17          10           6           8             0431            NaN           7642       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1          00                 0
    5   87d4a64f-3281-461c-886c-e890373fe706                 1        495  a02RM-~~~58AM~~00B      University of Dayton             2       Maura Collins   -230138  Reception               -         NaN      NaN      NaN          5        8           A                 NaN              01                  00                    1                        6         00B      19       9      11      15      10       7           1          16          17          10           6           8             0431            NaN           7642   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         00B                 1
    6   87d4a64f-3281-461c-886c-e890373fe706                 1        497   a08ET#~~~~8C~~~00      University of Dayton             8     Brooke Westbeld   -232525        Set               #         NaN      NaN        ~        NaN        8           C                 NaN              01                  00                    1                        6          00      19       9      11      15      10       7           1          16          17          10           6           8             3147            NaN            NaN   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1          00                 1
    7   87d4a64f-3281-461c-886c-e890373fe706                 1        499  a10AT-X5~46CH2~00F      University of Dayton            10      Jamie Peterson    -11802     Attack               -          X5      NaN      NaN          4        6           C                   2              01                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4512           5522           8150   Reception      Reception          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         NaN                 1
    8   87d4a64f-3281-461c-886c-e890373fe706                 1        499   *11BT+~~~~2C~~~00  University of Louisville            11      Anna Stevenson   -278838      Block               +         NaN      NaN      NaN        NaN        2           C                 NaN              01                  00                    1                        6          00      19       9      11      15      10       7           1          16          17          10           6           8             4578            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1          00                 2
    9   87d4a64f-3281-461c-886c-e890373fe706                 1        500  *19DT+~~~42AB~~00B  University of Louisville            19     Shannon Shields   -296094        Dig               +         NaN      NaN      NaN          4        2           A                 NaN              01                  00                    1                        6         00B      19       9      11      15      10       7           1          16          17          10           6           8             4512           5522           5912       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         00B                 2
    10  87d4a64f-3281-461c-886c-e890373fe706                 1        502   *08EH#~~~~8A~~~00  University of Louisville             8       Lexi Hamilton    -75970        Set               #         NaN      NaN        ~        NaN        8           A                 NaN              01                  00                    1                        6          00      19       9      11      15      10       7           1          16          17          10           6           8             2859            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1          00                 2
    11  87d4a64f-3281-461c-886c-e890373fe706                 1        504  *09AH#V5~41BH2~00F  University of Louisville             9     Claire Chaussee   -225496     Attack               #          V5      NaN      NaN          4        1           B                   2              01                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4316           5517           7918       Serve  BP-Transition          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         NaN                 2
    12  87d4a64f-3281-461c-886c-e890373fe706                 1        504   a17BH=~~~~2B~~~00      University of Dayton            17          Sierra Pla    -11804      Block               =         NaN      NaN      NaN        NaN        2           B                 NaN              01                  00                    1                        6          00      19       9      11      15      10       7           1          16          17          10           6           8             4583            NaN            NaN   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1          00                 3
    13  87d4a64f-3281-461c-886c-e890373fe706                 1        504             *p01:00  University of Louisville           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              01                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4493            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         NaN                 3
    18  87d4a64f-3281-461c-886c-e890373fe706                 1        519   *19SM#~~~71C~~~+1  University of Louisville            19     Shannon Shields   -296094      Serve               #         NaN      NaN      NaN          7        1           C                 NaN              02                  00                    1                        6          +1      19       9      11      15      10       7           1          16          17          10           6           8             0529            NaN           7728       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             2          +1                 0
    19  87d4a64f-3281-461c-886c-e890373fe706                 1        521  a01RM=~~~51CM~~-1B      University of Dayton             1  Mikaylah Van Lanen   -231069  Reception               =         NaN      NaN      NaN          5        1           C                 NaN              02                  00                    1                        6         -1B      19       9      11      15      10       7           1          16          17          10           6           8             0529            NaN           7728   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             2         -1B                 1
    20  87d4a64f-3281-461c-886c-e890373fe706                 1        522             *p02:00  University of Louisville           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              02                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4293            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             2         NaN                 1
    25  87d4a64f-3281-461c-886c-e890373fe706                 1        547   *19SM-~~~71C~~~+2  University of Louisville            19     Shannon Shields   -296094      Serve               -         NaN      NaN      NaN          7        1           C                 NaN              03                  00                    1                        6          +2      19       9      11      15      10       7           1          16          17          10           6           8             0526            NaN           7728       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             3          +2                 0
    26  87d4a64f-3281-461c-886c-e890373fe706                 1        548  a01RM+~~~51CR~~-2B      University of Dayton             1  Mikaylah Van Lanen   -231069  Reception               +         NaN      NaN      NaN          5        1           C                 NaN              03                  00                    1                        6         -2B      19       9      11      15      10       7           1          16          17          10           6           8             0526            NaN           7728   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             3         -2B                 1
    27  87d4a64f-3281-461c-886c-e890373fe706                 1        549   a08EQ#K1C~3A~~~-2      University of Dayton             8     Brooke Westbeld   -232525        Set               #         NaN       K1        C        NaN        3           A                 NaN              03                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4252            NaN            NaN   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             3         NaN                 1
    28  87d4a64f-3281-461c-886c-e890373fe706                 1        550  a16AQ=X1~31AH1~-2F      University of Dayton            16        Olivia Dubay     14555     Attack               =          X1      NaN      NaN          3        1           A                   1              03                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4444            NaN           8913   Reception      Reception          1           17               42  University of Louisville  University of Louisville      University of Dayton             3         NaN                 1
    29  87d4a64f-3281-461c-886c-e890373fe706                 1        551             *p03:00  University of Louisville           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              03                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             1187            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             3         NaN                 2
    34  87d4a64f-3281-461c-886c-e890373fe706                 1        565   *19SM#~~~71B~~~+3  University of Louisville            19     Shannon Shields   -296094      Serve               #         NaN      NaN      NaN          7        1           B                 NaN              04                  00                    1                        6          +3      19       9      11      15      10       7           1          16          17          10           6           8             0527            NaN           8017       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             4          +3                 0
    35  87d4a64f-3281-461c-886c-e890373fe706                 1        566  a01RM=~~~51BL~~-3B      University of Dayton             1  Mikaylah Van Lanen   -231069  Reception               =         NaN      NaN      NaN          5        1           B                 NaN              04                  00                    1                        6         -3B      19       9      11      15      10       7           1          16          17          10           6           8             0527            NaN           8017   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             4         -3B                 1
    36  87d4a64f-3281-461c-886c-e890373fe706                 1        568             *p04:00  University of Louisville           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              04                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             -113            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             4         NaN                 1
    41  87d4a64f-3281-461c-886c-e890373fe706                 1        583   *19SM#~~~71C~~~+4  University of Louisville            19     Shannon Shields   -296094      Serve               #         NaN      NaN      NaN          7        1           C                 NaN              05                  00                    1                        6          +4      19       9      11      15      10       7           1          16          17          10           6           8             0529            NaN           7925       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             5          +4                 0
    42  87d4a64f-3281-461c-886c-e890373fe706                 1        584  a02RM=~~~51CR~~-4B      University of Dayton             2       Maura Collins   -230138  Reception               =         NaN      NaN      NaN          5        1           C                 NaN              05                  00                    1                        6         -4B      19       9      11      15      10       7           1          16          17          10           6           8             0529            NaN           7925   Reception            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             5         -4B                 1
    43  87d4a64f-3281-461c-886c-e890373fe706                 1        586             *p05:00  University of Louisville           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              05                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             2293            NaN            NaN       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             5         NaN                 1
    48  87d4a64f-3281-461c-886c-e890373fe706                 1        602   *19SM-~~~79D~~~+5  University of Louisville            19     Shannon Shields   -296094      Serve               -         NaN      NaN      NaN          7        9           D                 NaN              05                  01                    1                        6          +5      19       9      11      15      10       7           1          16          17          10           6           8             0532            NaN           7631       Serve            nan          1           17               42      University of Dayton  University of Louisville      University of Dayton             6          +5                 0
    49  87d4a64f-3281-461c-886c-e890373fe706                 1        603  a02RM#~~~59DR~~-5B      University of Dayton             2       Maura Collins   -230138  Reception               #         NaN      NaN      NaN          5        9           D                 NaN              05                  01                    1                        6         -5B      19       9      11      15      10       7           1          16          17          10           6           8             0532            NaN           7631   Reception            nan          1           17               42      University of Dayton  University of Louisville      University of Dayton             6         -5B                 1
    50  87d4a64f-3281-461c-886c-e890373fe706                 1        604   a08ET#K1F~3C~~~-5      University of Dayton             8     Brooke Westbeld   -232525        Set               #         NaN       K1        F        NaN        3           C                 NaN              05                  01                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4549            NaN            NaN   Reception            nan          1           17               42      University of Dayton  University of Louisville      University of Dayton             6         NaN                 1
    51  87d4a64f-3281-461c-886c-e890373fe706                 1        605  a10AT#X5~45BH4~-5F      University of Dayton            10      Jamie Peterson    -11802     Attack               #          X5      NaN      NaN          4        5           B                   4              05                  01                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4513            NaN           8469   Reception      Reception          1           17               42      University of Dayton  University of Louisville      University of Dayton             6         NaN                 1
    52  87d4a64f-3281-461c-886c-e890373fe706                 1        606             ap05:01      University of Dayton           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              05                  01                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             1631            NaN            NaN   Reception            nan          1           17               42      University of Dayton  University of Louisville      University of Dayton             6         NaN                 2
    57  87d4a64f-3281-461c-886c-e890373fe706                 1        623   a02SM+~~~54A~~~-4      University of Dayton             2       Maura Collins   -230138      Serve               +         NaN      NaN      NaN          5        4           A                 NaN              06                  01                    1                        5          -4      19       9      11      15      10       7          16          17          10           6           8           1             0122            NaN           6367       Serve            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7          -4                 0
    58  87d4a64f-3281-461c-886c-e890373fe706                 1        625  *11RM-~~~54AR~~+4F  University of Louisville            11      Anna Stevenson   -278838  Reception               -         NaN      NaN      NaN          5        4           A                 NaN              06                  01                    1                        5         +4F      19       9      11      15      10       7          16          17          10           6           8           1             0122            NaN           6367   Reception            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         +4F                 1
    59  87d4a64f-3281-461c-886c-e890373fe706                 1        627   *19ET#~~~~8C~~~+4  University of Louisville            19     Shannon Shields   -296094        Set               #         NaN      NaN        ~        NaN        8           C                 NaN              06                  01                    1                        5          +4      19       9      11      15      10       7          16          17          10           6           8           1             3146            NaN            NaN   Reception            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7          +4                 1
    60  87d4a64f-3281-461c-886c-e890373fe706                 1        628  *09AT+X5~46CH2~+4F  University of Louisville             9     Claire Chaussee   -225496     Attack               +          X5      NaN      NaN          4        6           C                   2              06                  01                    1                        5         NaN      19       9      11      15      10       7          16          17          10           6           8           1             4210           5525           7851   Reception      Reception          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         NaN                 1
    61  87d4a64f-3281-461c-886c-e890373fe706                 1        628   a06BT/~~~~2C~~~-4      University of Dayton             6        Amelia Moore   -230139      Block               /         NaN      NaN      NaN        NaN        2           C                 NaN              06                  01                    1                        5          -4      19       9      11      15      10       7          16          17          10           6           8           1             4575            NaN            NaN       Serve            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7          -4                 2
    62  87d4a64f-3281-461c-886c-e890373fe706                 1        629  *15DT+~~~43CC~~+4F  University of Louisville            15          Aiko Jones   -224838        Dig               +         NaN      NaN      NaN          4        3           C                 NaN              06                  01                    1                        5         +4F      19       9      11      15      10       7          16          17          10           6           8           1             5890           4575           5650   Reception            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         +4F                 2
    63  87d4a64f-3281-461c-886c-e890373fe706                 1        630   *19ET#~~~~8C~~~+4  University of Louisville            19     Shannon Shields   -296094        Set               #         NaN      NaN        ~        NaN        8           C                 NaN              06                  01                    1                        5          +4      19       9      11      15      10       7          16          17          10           6           8           1             3240            NaN            NaN   Reception            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7          +4                 2
    64  87d4a64f-3281-461c-886c-e890373fe706                 1        631  *09AT#X5~49DT2~+4F  University of Louisville             9     Claire Chaussee   -225496     Attack               #          X5      NaN      NaN          4        9           D                   2              06                  01                    1                        5         NaN      19       9      11      15      10       7          16          17          10           6           8           1             4414            NaN           7024   Reception  SO-Transition          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         NaN                 2
    65  87d4a64f-3281-461c-886c-e890373fe706                 1        632  a08DT=~~~49DS~~-4B      University of Dayton             8     Brooke Westbeld   -232525        Dig               =         NaN      NaN      NaN          4        9           D                 NaN              06                  01                    1                        5         -4B      19       9      11      15      10       7          16          17          10           6           8           1             4414            NaN           7024       Serve            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         -4B                 3
    66  87d4a64f-3281-461c-886c-e890373fe706                 1        634             *p06:01  University of Louisville           NaN                 NaN       NaN      Point             NaN         NaN      NaN      NaN        NaN      NaN         NaN                 NaN              06                  01                    1                        5         NaN      19       9      11      15      10       7          16          17          10           6           8           1             -155            NaN            NaN   Reception            nan          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         NaN                 3
    71  87d4a64f-3281-461c-886c-e890373fe706                 1        652   *09SM/~~~97A~~~+5  University of Louisville             9     Claire Chaussee   -225496      Serve               /         NaN      NaN      NaN          9        7           A                 NaN              07                  01                    6                        5          +5       9      11      15      10       7      19          16          17          10           6           8           1             0463            NaN           7473       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             8          +5                 0
    Attacks filtered
                                     match_id video_file_number video_time                code                      team player_number      player_name player_id   skill evaluation_code attack_code set_code set_type start_zone end_zone end_subzone num_players_numeric home_team_score visiting_team_score home_setter_position visiting_setter_position custom_code home_p1 home_p2 home_p3 home_p4 home_p5 home_p6 visiting_p1 visiting_p2 visiting_p3 visiting_p4 visiting_p5 visiting_p6 start_coordinate mid_coordinate end_coordinate point_phase   attack_phase set_number home_team_id visiting_team_id              point_won_by              serving_team            receiving_team  rally_number custom_code  possesion_number
    7    87d4a64f-3281-461c-886c-e890373fe706                 1        499  a10AT-X5~46CH2~00F      University of Dayton            10   Jamie Peterson    -11802  Attack               -          X5      NaN      NaN          4        6           C                   2              01                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4512           5522           8150   Reception      Reception          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         NaN                 1
    11   87d4a64f-3281-461c-886c-e890373fe706                 1        504  *09AH#V5~41BH2~00F  University of Louisville             9  Claire Chaussee   -225496  Attack               #          V5      NaN      NaN          4        1           B                   2              01                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4316           5517           7918       Serve  BP-Transition          1           17               42  University of Louisville  University of Louisville      University of Dayton             1         NaN                 2
    28   87d4a64f-3281-461c-886c-e890373fe706                 1        550  a16AQ=X1~31AH1~-2F      University of Dayton            16     Olivia Dubay     14555  Attack               =          X1      NaN      NaN          3        1           A                   1              03                  00                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4444            NaN           8913   Reception      Reception          1           17               42  University of Louisville  University of Louisville      University of Dayton             3         NaN                 1
    51   87d4a64f-3281-461c-886c-e890373fe706                 1        605  a10AT#X5~45BH4~-5F      University of Dayton            10   Jamie Peterson    -11802  Attack               #          X5      NaN      NaN          4        5           B                   4              05                  01                    1                        6         NaN      19       9      11      15      10       7           1          16          17          10           6           8             4513            NaN           8469   Reception      Reception          1           17               42      University of Dayton  University of Louisville      University of Dayton             6         NaN                 1
    60   87d4a64f-3281-461c-886c-e890373fe706                 1        628  *09AT+X5~46CH2~+4F  University of Louisville             9  Claire Chaussee   -225496  Attack               +          X5      NaN      NaN          4        6           C                   2              06                  01                    1                        5         NaN      19       9      11      15      10       7          16          17          10           6           8           1             4210           5525           7851   Reception      Reception          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         NaN                 1
    64   87d4a64f-3281-461c-886c-e890373fe706                 1        631  *09AT#X5~49DT2~+4F  University of Louisville             9  Claire Chaussee   -225496  Attack               #          X5      NaN      NaN          4        9           D                   2              06                  01                    1                        5         NaN      19       9      11      15      10       7          16          17          10           6           8           1             4414            NaN           7024   Reception  SO-Transition          1           17               42  University of Louisville      University of Dayton  University of Louisville             7         NaN                 2
    73   87d4a64f-3281-461c-886c-e890373fe706                 1        653  *15AO+~~~27CT0~+5F  University of Louisville            15       Aiko Jones   -224838  Attack               +         NaN      NaN      NaN          2        7           C                   0              07                  01                    6                        5         NaN       9      11      15      10       7      19          16          17          10           6           8           1             4570            NaN           6987       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             8         NaN                 1
    75   87d4a64f-3281-461c-886c-e890373fe706                 1        656  *15AO+~~~22DT1~+5F  University of Louisville            15       Aiko Jones   -224838  Attack               +         NaN      NaN      NaN          2        2           D                   1              07                  01                    6                        5         NaN       9      11      15      10       7      19          16          17          10           6           8           1             4572            NaN           6331       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             8         NaN                 2
    77   87d4a64f-3281-461c-886c-e890373fe706                 1        658  *15AO-~~~26CP2~+5F  University of Louisville            15       Aiko Jones   -224838  Attack               -         NaN      NaN      NaN          2        6           C                   2              07                  01                    6                        5         NaN       9      11      15      10       7      19          16          17          10           6           8           1             4572           5469           8060       Serve            nan          1           17               42  University of Louisville  University of Louisville      University of Dayton             8         NaN                 3
    81   87d4a64f-3281-461c-886c-e890373fe706                 1        662  a10AH=V5~45CP2~-5F      University of Dayton            10   Jamie Peterson    -11802  Attack               =          V5      NaN      NaN          4        5           C                   2              07                  01                    6                        5         NaN       9      11      15      10       7      19          16          17          10           6           8           1             4212            NaN           7893   Reception  SO-Transition          1           17               42  University of Louisville  University of Louisville      University of Dayton             8         NaN                 4
    91   87d4a64f-3281-461c-886c-e890373fe706                 1        770  *15AT=X6~29AH4~+6F  University of Louisville            15       Aiko Jones   -224838  Attack               =          X6      NaN      NaN          2        9           A                   4              07                  02                    6                        5         NaN       9      11      15      10       7      19          16          17          10           6           8           1             4480            NaN           7207       Serve  BP-Transition          1           17               42      University of Dayton  University of Louisville      University of Dayton             9         NaN                 1
    101  87d4a64f-3281-461c-886c-e890373fe706                 1        797  *11AQ#X1~39DH1~+5F  University of Louisville            11   Anna Stevenson   -278838  Attack               #          X1      NaN      NaN          3        9           D                   1              08                  02                    6                        4         NaN       9      11      15      10       7      19           3          10           6           8           1          16             4246            NaN           7026   Reception      Reception          1           17               42  University of Louisville      University of Dayton  University of Louisville            10         NaN                 1
    118  87d4a64f-3281-461c-886c-e890373fe706                 1        838  *10AO-~~~79DP2~+5F  University of Louisville            10      Mel McHenry    -75967  Attack               -         NaN      NaN      NaN          7        9           D                   2              09                  03                    5                        3         NaN      11      15      10       7      19       9          10           6           8           5          16           3             3232            NaN           7329   Reception      Reception          1           17               42  University of Louisville      University of Dayton  University of Louisville            12         NaN                 1
    121  87d4a64f-3281-461c-886c-e890373fe706                 1        841  a08AM-X3~39CH1~-5F      University of Dayton             8  Brooke Westbeld   -232525  Attack               -          X3      NaN      NaN          3        9           C                   1              09                  03                    5                        3         NaN      11      15      10       7      19       9          10           6           8           5          16           3             4647            NaN           6934       Serve  BP-Transition          1           17               42  University of Louisville      University of Dayton  University of Louisville            12         NaN                 2
    124  87d4a64f-3281-461c-886c-e890373fe706                 1        846  *15AH#V6~25BH2~+5F  University of Louisville            15       Aiko Jones   -224838  Attack               #          V6      NaN      NaN          2        5           B                   2              09                  03                    5                        3         NaN      11      15      10       7      19       9          10           6           8           5          16           3             4484           5482           8078   Reception  SO-Transition          1           17               42  University of Louisville      University of Dayton  University of Louisville            12         NaN                 3
    136  87d4a64f-3281-461c-886c-e890373fe706                 1        878  a08AO#PP~31B~~~-6F      University of Dayton             8  Brooke Westbeld   -232525  Attack               #          PP      NaN      NaN          3        1           B                   ~              09                  04                    4                        3         NaN      12      10       7      25       9      11          10           6           8           5          16           3             4554            NaN           8114   Reception      Reception          1           17               42      University of Dayton  University of Louisville      University of Dayton            13         NaN                 1
    152  87d4a64f-3281-461c-886c-e890373fe706                 1        926  *07AN#CB~27BH1~+4F  University of Louisville             7      Emily Scott   -224837  Attack               #          CB      NaN      NaN          2        7           B                   1              10                  05                    4                        2         NaN      12      10       7      25       9      11           6           8           5          16           3          10             4490           5580           6670   Reception      Reception          1           17               42  University of Louisville      University of Dayton  University of Louisville            15         NaN                 1
    162  87d4a64f-3281-461c-886c-e890373fe706                 1        946  a08AO-PP~34D~~~-5F      University of Dayton             8  Brooke Westbeld   -232525  Attack               -          PP      NaN      NaN          3        4           D                   ~              10                  06                    3                        2         NaN      10       7      25       9      11      12           6           8           5          16           3          10             4668            NaN           5883   Reception      Reception          1           17               42      University of Dayton  University of Louisville      University of Dayton            16         NaN                 1
    165  87d4a64f-3281-461c-886c-e890373fe706                 1        950  *25AT-X6~26CP4~+5F  University of Louisville            25    Amaya Tillman   -278840  Attack               -          X6      NaN      NaN          2        6           C                   4              10                  06                    3                        2         NaN      10       7      25       9      11      12           6           8           5          16           3          10             4186            NaN           7850       Serve  BP-Transition          1           17               42      University of Dayton  University of Louisville      University of Dayton            16         NaN                 2
    168  87d4a64f-3281-461c-886c-e890373fe706                 1        953  a16AQ-X1~38DH1~-5F      University of Dayton            16     Olivia Dubay     14555  Attack               -          X1      NaN      NaN          3        8           D                   1              10                  06                    3                        2         NaN      10       7      25       9      11      12           6           8           5          16           3          10             4541            NaN           7650   Reception  SO-Transition          1           17               42      University of Dayton  University of Louisville      University of Dayton            16         NaN                 3
